import { Component } from '@angular/core';
import { Router } from '@angular/router';
import { ViewChild } from '@angular/core';
import { MatBottomSheet, MAT_BOTTOM_SHEET_DATA, MatBottomSheetRef } from '@angular/material';
import { BackdropBackLayerToolbarComponent, BackdropComponent } from 'nereo-material';
import { Inject } from '@angular/core';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent {
  @ViewChild(BackdropComponent)
  backdrop: BackdropComponent;

  isBackdropRevealed = false;

  title = 'Coview';
  showMenuButton: boolean;
  showLogo = false;

  subtitleIcon = '';
  subtitle = '';
  showMoreActions = false;

  constructor(private router: Router, private bottomSheet: MatBottomSheet){
    this.router.events.subscribe((event: any) => {
      console.log(event.url);
      switch(event.url){
        case '/home':
          this.showMenuButton = true;  
          this.showLogo = true;
          this.title = 'Coview';
          this.subtitle = 'Pending Inspections';
          this.subtitleIcon = 'assignment';
          this.showMoreActions = false;
          break;
          case '/inspection':
        case '/inspection/general-info':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'General Info';
          this.subtitleIcon = 'info';
          this.showMoreActions = false;
          break;
        case '/inspection/details':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Order Details';
          this.subtitleIcon = 'details';
          this.showMoreActions = false;
          break;
        case '/inspection/documents':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Attachments';
          this.subtitleIcon = 'attach_file';
          this.showMoreActions = false;
          break;
        case '/inspection/packaging':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Packaging';
          this.subtitleIcon = 'widgets';
          this.showMoreActions = false;
          this.showMoreActions = false;
          break;   
        case '/inspection/items':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Items and Discrepacncies';
          this.subtitleIcon = 'list';
          this.showMoreActions = false;
          break;
        case '/inspection/verification':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Verification';
          this.subtitleIcon = 'check';
          this.showMoreActions = false;
          break;
        case '/inspection/result':
          this.showMenuButton = true;  
          this.showLogo = false;
          this.title = 'Inspection';
          this.subtitle = 'Result';
          this.subtitleIcon = 'feedback';
          this.showMoreActions = false;
          break;
        case '/item':
          this.showMenuButton = false;  
          this.showLogo = false;
          this.title = 'Item';
          this.subtitle = 'Item Details';
          this.subtitleIcon = 'details';
          this.showMoreActions = true;
          break;              
        default: 
          this.showLogo = false;
          this.showMenuButton = true;
          this.title = 'Coview';
          this.subtitle = '';
          this.subtitleIcon = '';
          this.showMoreActions = false;
          break;
      }
    });
  }

  revealBackdrop(){
    this.isBackdropRevealed = true;
    this.backdrop.reveal();
  }
  concealBackdrop(){
    this.isBackdropRevealed = false;
    this.backdrop.conceal();
  }

  navigateBack(){
    window.history.back();
  }

  openBottomSheet(){
    this.bottomSheet.open(ItemBottomSheetComponent, {
      data: [
        {icon: 'archive', name: 'Archive'},
        {icon: 'history', name: 'History'},
        {icon: 'delete', name: 'Delete'},
      ]
    });
  }
}

@Component({
  selector: 'app-item-bottom-sheet',
  template: `
              <mat-list>
                <mat-list-item *ngFor="let action of actions" (click)="close()">
                  <mat-icon mat-list-icon>{{action.icon}}</mat-icon>
                  <h4 mat-line>{{action.name}}</h4>
                </mat-list-item>
              </mat-list>
            `
})
export class ItemBottomSheetComponent {
  actions: any[];
  constructor(
    private bottomSheetRef: MatBottomSheetRef<ItemBottomSheetComponent>,
    @Inject(MAT_BOTTOM_SHEET_DATA) private data: any){
    this.actions = data;
  }

  close(){
    this.bottomSheetRef.dismiss();
  }
}
