import { Component, OnInit } from '@angular/core';
import { MatTabChangeEvent, MatTabGroup } from '@angular/material';
import { Router } from '@angular/router';
import { ActivatedRoute } from '@angular/router';
import { ViewChild } from '@angular/core';
import { ChangeDetectorRef } from '@angular/core';

@Component({
  selector: 'app-inspection',
  templateUrl: './inspection.component.html',
  styleUrls: ['./inspection.component.scss']
})
export class InspectionComponent implements OnInit {
  @ViewChild(MatTabGroup) tabGroup: MatTabGroup;

  numberOfSelectedItems: number = 0;
  actions: any[] = [
    {
      name: 'delete',
      icon: 'delete'
    }
  ]

  TAB_TO_INDEX_MAPPING = {
    "general-info": 0,
    "details": 1,
    "documents": 2,
    "packaging" : 3,
    "items": 4,
    "verification" : 5,
    "result" : 6
  }

  constructor(private route: ActivatedRoute, 
              private router: Router,
              private changeDetector : ChangeDetectorRef) { }

  ngOnInit() {
  }
  
  ngAfterViewInit(){ 
    let currentActiveRoute: string = this.getCurrentTabFromUrl();
			let selectedTabIndex = this.TAB_TO_INDEX_MAPPING[currentActiveRoute];
			if (selectedTabIndex){
				this.tabGroup.selectedIndex = selectedTabIndex;				
				this.changeDetector.detectChanges();				
			}
			else{
				this.tabGroup.selectedIndex = 0;
			}
  }

  onSelectedIndexChange(event: number){
    switch(event){
      case 0:
      this.router.navigate(['./general-info'], { relativeTo: this.route });
        break;
      case 1:
        this.router.navigate(['./details'], { relativeTo: this.route });
        break;
      case 2:
      this.router.navigate(['./documents'], { relativeTo: this.route });
        break;
      case 3:
      this.router.navigate(['./packaging'], { relativeTo: this.route });
        break;
      case 4:
      this.router.navigate(['./items'], { relativeTo: this.route });
        break;
      case 5:
      this.router.navigate(['./verification'], { relativeTo: this.route });
        break;
      case 6:
      this.router.navigate(['./result'], { relativeTo: this.route });
        break;
    }
  }

  getCurrentTabFromUrl(): string{
		return this.router.url.substr(this.router.url.lastIndexOf("/") + 1);
  }
  
  selectionChanged(e){
    if (e.checked == true){
      console.log("INCREMENTING!");
      this.incrementSelectedItems();
    }
    else {
      this.decrementSelectedItems();
    }
  }

  incrementSelectedItems(){
    this.numberOfSelectedItems++;
  }

  decrementSelectedItems(){
    this.numberOfSelectedItems--;
    if (this.numberOfSelectedItems < 0){
      this.numberOfSelectedItems = 0;
    }
  }

  clearSelection(){
    this.numberOfSelectedItems = 0;
  }

}
